"""
Version information.
"""

__version__ = '0.1.0'
__author__ = 'Sumedh Patil'
__author_email__ = 'sumedh@aipresso.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2025 Sumedh Patil, Aipresso Limited, UK'
